class FileConfig:
    def __init__(self, uri, file_format, timestamp_field):
        self.uri = uri
        self.file_format = file_format
        self.timestamp_field = timestamp_field


class BatchSource:
    def __init__(self, name, batch_config):
        self.name = name
        self.batch_config = batch_config


def create_batch_source(name, uri, file_format, timestamp_field):
    file_config = FileConfig(uri=uri, file_format=file_format, timestamp_field=timestamp_field)
    batch_source = BatchSource(name=name, batch_config=file_config)
    return batch_source



import pandas as pd
import pyarrow as pa
import pyarrow.parquet as pq

# Sample dataset
data = [
    ("2023-03-30 09:00:00", "device_1", "Device One", "2023-03-30 08:59:00"),
    ("2023-03-30 09:15:00", "device_2", "Device Two", "2023-03-30 09:14:00"),
    ("2023-03-30 09:30:00", "device_3", "Device Three", "2023-03-30 09:29:00"),
]

# Define column names
column_names = ["timestamp", "device_id", "name", "created_at"]

# Create a DataFrame from the dataset
df = pd.DataFrame(data, columns=column_names)

# Convert the timestamp and created_at columns to datetime objects
df["timestamp"] = pd.to_datetime(df["timestamp"])
df["created_at"] = pd.to_datetime(df["created_at"])

# Save the DataFrame as a Parquet file
table = pa.Table.from_pandas(df)
pq.write_table(table,'output.parquet', compression='snappy')

print("Parquet file created: output.parquet")
